@@ -477,7 +477,7 @@ class ParamEditor(QtWidgets.QDockWidget):
     else:
       menu = QtWidgets.QMenu(title, parent)
     for proc in self.procToParamsMapping:
-      menu.addAction(proc.name, lambda: proc.run())
+      menu.addAction(proc.name, lambda _p=proc: _p.run())
     return menu
 
   def addDirItemsToMenu(self, parentMenu: QtWidgets.QMenu, removeExistingChildren=True):
