@@ -17,7 +17,6 @@ __all__ = ['ProcessIO', 'ProcessStage', 'NestedProcess', 'AtomicProcess']
 _infoType = t.List[t.Union[t.List, t.Dict[str, t.Any]]]
 StrList = t.List[str]
 StrCol = t.Collection[str]
-class _DUPLICATE_INFO: pass
 
 class ProcessIO(dict):
   """
@@ -106,6 +105,8 @@ class ProcessStage(ABC):
   mainResultKeys: StrList = None
   mainInputKeys: StrList = None
 
+  class _DUPLICATE_INFO: pass
+  """Identifies information that is the same in two contiguous stages"""
 
   def __repr__(self) -> str:
     selfCls = type(self)
@@ -375,6 +376,6 @@ class NestedProcess(ProcessStage):
       for lastInfo in prevInfos:
         for key in set(info.keys()).intersection(lastInfo.keys()) - {'name'}:
           if np.array_equal(info[key], lastInfo[key]):
-            validInfo[key] = _DUPLICATE_INFO
+            validInfo[key] = cls._DUPLICATE_INFO
       validInfos.append(validInfo)
     return validInfos
\ No newline at end of file
